@@ -1,6 +1,5 @@
 library(testthat)
 library(dplyr)
-library(rsample)
 
 skip_on_cran()
 skip_if_not_installed("xgboost")
@@ -14,9 +13,9 @@ data("attrition", package = "modeldata")
 
 # Data for classification problem testing
 set.seed(42)
-credit_data_split <- initial_split(credit_data, strata = "Status")
-credit_data_train <- training(credit_data_split)
-credit_data_test <- testing(credit_data_split)
+credit_data_split <- rsample::initial_split(credit_data, strata = "Status")
+credit_data_train <- rsample::training(credit_data_split)
+credit_data_test <- rsample::testing(credit_data_split)
 
 set.seed(2393)
 credit_data_small <- dplyr::sample_n(credit_data_train, 30)
@@ -29,21 +28,23 @@ rec_credit <- credit_data_train %>%
 
 xgb_credit_train <- xgboost::xgb.DMatrix(
   data = as.matrix(bake(rec_credit, new_data = NULL)),
-  label = ifelse(credit_data_train[["Status"]] == "bad", 0, 1)
+  label = ifelse(credit_data_train[["Status"]] == "bad", 0, 1),
+  nthread = 1
 )
 
 xgb_credit_test <- xgboost::xgb.DMatrix(
   data = as.matrix(bake(rec_credit, new_data = credit_data_test)),
-  label = ifelse(credit_data_test[["Status"]] == "bad", 0, 1)
+  label = ifelse(credit_data_test[["Status"]] == "bad", 0, 1),
+  nthread = 1
 )
 
 # Data for multi-classification problem testing
 set.seed(42)
 attrition <- attrition %>%
   mutate(EducationField = as.integer(EducationField) - 1)
-attrition_data_split <- initial_split(attrition, strata = "EducationField")
-attrition_data_train <- training(attrition_data_split)
-attrition_data_test <- testing(attrition_data_split)
+attrition_data_split <- rsample::initial_split(attrition, strata = "EducationField")
+attrition_data_train <- rsample::training(attrition_data_split)
+attrition_data_test <- rsample::testing(attrition_data_split)
 
 set.seed(2393)
 attrition_data_small <- dplyr::sample_n(attrition_data_train, 10)
@@ -56,20 +57,22 @@ rec_attrition <- attrition_data_train %>%
 
 xgb_attrition_train <- xgboost::xgb.DMatrix(
   data = as.matrix(bake(rec_attrition, new_data = NULL)),
-  label = attrition_data_train$EducationField
+  label = attrition_data_train$EducationField,
+  nthread = 1
 )
 
 xgb_attrition_test <- xgboost::xgb.DMatrix(
   data = as.matrix(bake(rec_attrition, new_data = attrition_data_test)),
-  label = attrition_data_test$EducationField
+  label = attrition_data_test$EducationField,
+  nthread = 1
 )
 
 ames$Sale_Price <- log10(ames$Sale_Price)
 # Data for regression problem testing (naive)
 set.seed(1773)
-ames_data_split <- initial_split(ames, strata = "Sale_Price")
-ames_data_train <- training(ames_data_split)
-ames_data_test <- testing(ames_data_split)
+ames_data_split <- rsample::initial_split(ames, strata = "Sale_Price")
+ames_data_train <- rsample::training(ames_data_split)
+ames_data_test <- rsample::testing(ames_data_split)
 
 set.seed(8134)
 ames_data_small <- dplyr::sample_n(ames_data_train, 10)
@@ -82,12 +85,14 @@ ames_rec <- ames_data_train %>%
 
 xgb_ames_train <- xgboost::xgb.DMatrix(
   data = as.matrix(bake(ames_rec, new_data = NULL)),
-  label = ames_data_train[["Sale_Price"]]
+  label = ames_data_train[["Sale_Price"]],
+  nthread = 1
 )
 
 xgb_ames_test <- xgboost::xgb.DMatrix(
   data = as.matrix(bake(ames_rec, new_data = ames_data_test)),
-  label = ames_data_test[["Sale_Price"]]
+  label = ames_data_test[["Sale_Price"]],
+  nthread = 1
 )
 
 set.seed(8497)
@@ -103,6 +108,8 @@ sim_tr_reg <- sim_data_reg(1000)
 sim_te_reg <- sim_data_reg(100)
 
 test_that("run_xgboost for classification", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   xgboost <- embed:::run_xgboost(
     xgb_credit_train,
     xgb_credit_test,
@@ -122,6 +129,8 @@ test_that("run_xgboost for classification", {
 })
 
 test_that("run_xgboost for multi-classification", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   xgboost <- embed:::run_xgboost(
     xgb_attrition_train,
     xgb_attrition_test,
@@ -141,6 +150,8 @@ test_that("run_xgboost for multi-classification", {
 })
 
 test_that("run_xgboost for regression", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   xgboost <- embed:::run_xgboost(
     xgb_ames_train,
     xgb_ames_test,
@@ -160,6 +171,8 @@ test_that("run_xgboost for regression", {
 })
 
 test_that("xgb_binning for classification", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   less_than_3.6 <- function() {
     utils::compareVersion("3.5.3", as.character(getRversion())) >= 0
   }
@@ -199,6 +212,8 @@ test_that("xgb_binning for classification", {
 })
 
 test_that("xgb_binning for multi-classification", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   less_than_3.6 <- function() {
     utils::compareVersion("3.5.3", as.character(getRversion())) >= 0
   }
@@ -237,6 +252,8 @@ test_that("xgb_binning for multi-classification", {
 })
 
 test_that("xgb_binning for regression", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   less_than_3.6 <- function() {
     utils::compareVersion("3.5.3", as.character(getRversion())) >= 0
   }
@@ -276,6 +293,8 @@ test_that("xgb_binning for regression", {
 })
 
 test_that("step_discretize_xgb for classification", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   set.seed(125)
   # General use
   xgb_rec <-
@@ -330,6 +349,8 @@ test_that("step_discretize_xgb for classification", {
 })
 
 test_that("step_discretize_xgb for multi-classification", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   set.seed(125)
   # General use
   xgb_rec <-
@@ -381,6 +402,8 @@ test_that("step_discretize_xgb for multi-classification", {
 })
 
 test_that("step_discretize_xgb for regression", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   # Skip on R < 3.6 since the rng is different.
   skip("Needs to determine why random numbers are different")
 
@@ -458,6 +481,8 @@ test_that("step_discretize_xgb for regression", {
 })
 
 test_that("xgb_binning() errors if only one class in outcome", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   const_outcome <- data.frame(
     outcome = factor(rep("a", 1000)),
     predictor = rep(1, 1000)
@@ -478,6 +503,8 @@ test_that("xgb_binning() errors if only one class in outcome", {
 })
 
 test_that("case weights step_discretize_xgb", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   sim_tr_cls_cw <- sim_tr_cls %>%
     mutate(weight = importance_weights(rep(1:0, each = 500)))
 
@@ -602,26 +629,6 @@ test_that("tunable", {
   )
 })
 
-test_that("tunable is setup to works with extract_parameter_set_dials works", {
-  skip_if_not_installed("dials")
-  
-  rec <- recipe(~., data = mtcars) %>%
-    step_discretize_xgb(
-      all_predictors(),
-      outcome = "mpg",
-      sample_val = hardhat::tune(),
-      learn_rate = hardhat::tune(),
-      num_breaks = hardhat::tune(),
-      tree_depth = hardhat::tune(),
-      min_n = hardhat::tune()
-    )
-  
-  params <- extract_parameter_set_dials(rec)
-  
-  expect_s3_class(params, "parameters")
-  expect_identical(nrow(params), 5L)
-})
-
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -676,9 +683,30 @@ test_that("empty selection tidy method works", {
 })
 
 test_that("printing", {
+  skip_on_cran() # because data.table uses all cores by default 
+  
   rec <- recipe(class ~ ., data = sim_tr_cls) %>%
     step_discretize_xgb(all_predictors(), outcome = "class")
   
   expect_snapshot(print(rec))
   expect_snapshot(prep(rec))
-})
\ No newline at end of file
+})
+
+test_that("tunable is setup to works with extract_parameter_set_dials", {
+  skip_if_not_installed("dials")
+  rec <- recipe(~., data = mtcars) %>%
+    step_discretize_xgb(
+      all_predictors(),
+      outcome = "mpg",
+      sample_val = hardhat::tune(),
+      learn_rate = hardhat::tune(),
+      num_breaks = hardhat::tune(),
+      tree_depth = hardhat::tune(),
+      min_n = hardhat::tune()
+    )
+  
+  params <- extract_parameter_set_dials(rec)
+  
+  expect_s3_class(params, "parameters")
+  expect_identical(nrow(params), 5L)
+})
