@@ -2,4 +2,4 @@ library(embed)
 library(dplyr)
 library(testthat)
 
-is_tf_available()
+embed:::is_tf_available()
