@@ -71,6 +71,19 @@ test_that("check_name() is used", {
   )
 })
 
+test_that("Do nothing for num_comps = 0 and keep_original_cols = FALSE", {
+  # https://github.com/tidymodels/recipes/issues/1152
+  
+  rec <- recipe(carb ~ ., data = mtcars) %>%
+    step_pca_truncated(all_predictors(), 
+                       num_comp = 0, keep_original_cols = FALSE) %>%
+    prep()
+  
+  res <- bake(rec, new_data = NULL)
+  
+  expect_identical(res, tibble::as_tibble(mtcars))
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
@@ -142,6 +155,64 @@ test_that("empty selection tidy method works", {
   expect_identical(tidy(rec, number = 1), expect)
 })
 
+test_that("keep_original_cols works", {
+  skip_if_not_installed("irlba")
+  skip_if_not_installed("modeldata")
+  
+  data(cells, package = "modeldata")
+  cells$case <- cells$class <- NULL
+  cells <- as.data.frame(scale(cells))
+  
+  new_names <- c("PC1")
+  
+  rec <- recipe(~., data = cells) %>%
+    step_pca_truncated(all_predictors(), num_comp = 1, 
+                       keep_original_cols = FALSE)
+  
+  rec <- prep(rec)
+  res <- bake(rec, new_data = NULL)
+  
+  expect_equal(
+    colnames(res),
+    new_names
+  )
+  
+  rec <- recipe(~., data = cells) %>%
+    step_pca_truncated(all_predictors(), num_comp = 1, 
+                       keep_original_cols = TRUE)
+  
+  rec <- prep(rec)
+  res <- bake(rec, new_data = NULL)
+  
+  expect_equal(
+    colnames(res),
+    c(names(cells), new_names)
+  )
+})
+
+test_that("keep_original_cols - can prep recipes with it missing", {
+  skip_if_not_installed("irlba")
+  skip_if_not_installed("modeldata")
+  
+  data(cells, package = "modeldata")
+  cells$case <- cells$class <- NULL
+  cells <- as.data.frame(scale(cells))
+  
+  rec <- recipe(~., data = cells) %>%
+    step_pca_truncated(all_predictors(), num_comp = 1)
+  
+  rec$steps[[1]]$keep_original_cols <- NULL
+  
+  expect_snapshot(
+    rec <- prep(rec)
+  )
+  
+  expect_error(
+    bake(rec, new_data = cells),
+    NA
+  )
+})
+
 test_that("printing", {
   rec <- recipe(mpg ~ ., data = mtcars) %>%
     step_pca_truncated(all_predictors(), num_comp = 2)
